@@ -5,7 +5,6 @@
 */
 
 #include "archivemailagent.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "archivemailagentadaptor.h"
 #include "archivemailagentsettings.h"
@@ -21,10 +20,11 @@ using namespace Qt::Literals::StringLiterals;
 #include <QTimer>
 #include <chrono>
 using namespace std::chrono_literals;
+using namespace Qt::Literals::StringLiterals;
 // #define DEBUG_ARCHIVEMAILAGENT 1
 
 ArchiveMailAgent::ArchiveMailAgent(const QString &id)
-    : Akonadi::AgentBase(id)
+    : Akonadi::AgentWidgetBase(id)
     , mTimer(new QTimer(this))
     , mArchiveManager(new ArchiveMailManager(this))
 {
