@@ -75,8 +75,9 @@ void FilterManager::Private::slotItemsFetchedForFilter(const Akonadi::Item::List
     }
 
     QList<MailFilter *> listMailFilters;
-    if (q->sender()->property("listFilters").isValid()) {
-        const QStringList listFilters = q->sender()->property("listFilters").toStringList();
+    const QVariant listFiltersProp = q->sender()->property("listFilters");
+    if (listFiltersProp.isValid()) {
+        const QStringList listFilters = listFiltersProp.toStringList();
         for (const QString &filterId : listFilters) {
             for (MailCommon::MailFilter *filter : std::as_const(mFilters)) {
                 if (filter->identifier() == filterId) {
@@ -288,7 +289,6 @@ FilterManager::FilterManager(QObject *parent)
     : QObject(parent)
     , d(new Private(this))
 {
-    readConfig();
 }
 
 FilterManager::~FilterManager()
@@ -321,8 +321,9 @@ void FilterManager::readConfig()
             auto it = std::max_element(d->mFilters.constBegin(), d->mFilters.constEnd(), [id](MailCommon::MailFilter *lhs, MailCommon::MailFilter *rhs) {
                 return lhs->requiredPart(id) < rhs->requiredPart(id);
             });
-            d->mRequiredParts[id] = (*it)->requiredPart(id);
-            d->mRequiredPartsBasedOnAll = qMax(d->mRequiredPartsBasedOnAll, d->mRequiredParts[id]);
+            const SearchRule::RequiredPart rp = (*it)->requiredPart(id);
+            d->mRequiredParts.insert(id, rp);
+            d->mRequiredPartsBasedOnAll = qMax(d->mRequiredPartsBasedOnAll, rp);
         }
     }
     // check if at least one filter is to be applied on inbound mail
@@ -571,7 +572,8 @@ MailCommon::SearchRule::RequiredPart FilterManager::requiredPart(const QString &
     if (id.isEmpty()) {
         return d->mRequiredPartsBasedOnAll;
     }
-    return d->mRequiredParts.contains(id) ? d->mRequiredParts[id] : SearchRule::Envelope;
+    auto it = d->mRequiredParts.constFind(id);
+    return it != d->mRequiredParts.cend() ? it.value() : SearchRule::Envelope;
 }
 
 void FilterManager::dump() const
@@ -600,7 +602,9 @@ void FilterManager::applySpecificFilters(const Akonadi::Item::List &selectedMess
     }
 
     itemFetchJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
-    itemFetchJob->setProperty("listFilters", QVariant::fromValue(listFilters));
+    if (!listFilters.isEmpty()) {
+        itemFetchJob->setProperty("listFilters", QVariant::fromValue(listFilters));
+    }
     itemFetchJob->setProperty("filterSet", QVariant::fromValue(static_cast<int>(filterSet)));
     itemFetchJob->setProperty("needsFullPayload", requiredPart != SearchRule::Envelope);
 
@@ -614,30 +618,7 @@ void FilterManager::applySpecificFilters(const Akonadi::Item::List &selectedMess
 
 void FilterManager::applyFilters(const Akonadi::Item::List &selectedMessages, FilterSet filterSet)
 {
-    Q_EMIT progressMessage(i18n("Filtering messages"));
-    d->mTotalProgressCount = selectedMessages.size();
-    d->mCurrentProgressCount = 0;
-
-    auto itemFetchJob = new Akonadi::ItemFetchJob(selectedMessages, this);
-    SearchRule::RequiredPart requiredParts = requiredPart(QString());
-    if (requiredParts == SearchRule::CompleteMessage) {
-        itemFetchJob->fetchScope().fetchFullPayload(true);
-    } else if (requiredParts == SearchRule::Header) {
-        itemFetchJob->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Header, true);
-    } else {
-        itemFetchJob->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Envelope, true);
-    }
-
-    itemFetchJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
-    itemFetchJob->setProperty("filterSet", QVariant::fromValue(static_cast<int>(filterSet)));
-    itemFetchJob->setProperty("needsFullPayload", requiredParts != SearchRule::Envelope);
-
-    connect(itemFetchJob, &Akonadi::ItemFetchJob::itemsReceived, this, [this](const Akonadi::Item::List &lst) {
-        d->slotItemsFetchedForFilter(lst);
-    });
-    connect(itemFetchJob, &Akonadi::ItemFetchJob::result, this, [this](KJob *job) {
-        d->itemsFetchJobForFilterDone(job);
-    });
+    applySpecificFilters(selectedMessages, requiredPart(QString()), QStringList(), filterSet);
 }
 
 bool FilterManager::hasAllFoldersFilter() const
