@@ -6,13 +6,13 @@
 
 #pragma once
 
-#include <Akonadi/AgentBase>
+#include <Akonadi/AgentWidgetBase>
 
 #include <MessageComposer/SendLaterInfo>
 
 class SendLaterManager;
 
-class SendLaterAgent : public Akonadi::AgentBase, public Akonadi::AgentBase::ObserverV3
+class SendLaterAgent : public Akonadi::AgentWidgetBase, public Akonadi::AgentBase::ObserverV3
 {
     Q_OBJECT
 public:
