@@ -6,10 +6,9 @@
 
 #pragma once
 
+#include <KSharedConfig>
 #include <QDialog>
 
-#include "unifiedmailboxmanager.h"
-
 class UnifiedMailbox;
 class UnifiedMailboxEditor : public QDialog
 {
