@@ -31,7 +31,7 @@ protected:
     }
 
 public:
-    enum TemplateContext {
+    enum class TemplateContext : int8_t {
         New,
         Reply,
         ReplyToAll,
@@ -143,7 +143,7 @@ public: // kmcommand
 KMAIL_EXPORT Composer *makeComposer(const KMime::Message::Ptr &msg = KMime::Message::Ptr(),
                                     bool lastSignState = false,
                                     bool lastEncryptState = false,
-                                    Composer::TemplateContext context = Composer::NoTemplate,
+                                    Composer::TemplateContext context = Composer::TemplateContext::NoTemplate,
                                     uint identity = 0,
                                     const QString &textSelection = QString(),
                                     const QString &customTemplate = QString());
