@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #include "kmcomposercreatenewcomposerjob.h"
 #include "editor/kmcomposerwin.h"
 #include "kmkernel.h"
-#include <MessageComposer/Composer>
 
+#include <MessageComposer/ComposerJob>
 #include <MessageComposer/MessageHelper>
 #include <TemplateParser/TemplateParserJob>
 
@@ -32,7 +32,7 @@ void KMComposerCreateNewComposerJob::start()
 
 void KMComposerCreateNewComposerJob::slotCreateNewComposer(bool forceCursorPosition)
 {
-    KMail::Composer *win = KMComposerWin::create(mMsg, false, false, KMail::Composer::New, mCurrentIdentity);
+    KMail::Composer *win = KMComposerWin::create(mMsg, false, false, KMail::Composer::TemplateContext::New, mCurrentIdentity);
     win->setCollectionForNewMessage(mCollectionForNewMessage);
     if (forceCursorPosition) {
         win->setFocusToEditor();
