@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -37,7 +37,7 @@ void FolderArchiveAgentJob::start()
         return;
     }
 
-    if (mInfo->folderArchiveType() == FolderArchiveAccountInfo::UniqueFolder) {
+    if (mInfo->folderArchiveType() == FolderArchiveAccountInfo::FolderArchiveType::UniqueFolder) {
         auto fetchCollection = new Akonadi::CollectionFetchJob(Akonadi::Collection(mInfo->archiveTopLevel()), Akonadi::CollectionFetchJob::Base);
         connect(fetchCollection, &Akonadi::CollectionFetchJob::result, this, &FolderArchiveAgentJob::slotFetchCollection);
     } else {
