@@ -12,6 +12,7 @@
 
 #include "identityaddvcarddialog.h"
 #include "identityeditvcarddialog.h"
+#include "identityexpirespamfolderdialog.h"
 #include "identityfolderrequester.h"
 #include "identityinvalidfolder.h"
 
@@ -703,6 +704,24 @@ IdentityDialog::IdentityDialog(QWidget *parent)
     label->setBuddy(mTemplatesFolderRequester);
     formLayout->addRow(label, mTemplatesFolderRequester);
 
+    // "Spam Folder" combo box and label:
+
+    mSpamFolderRequester = new IdentityFolderRequester(tab);
+    mSpamFolderRequester->setSelectFolderTitleDialog(i18n("Select Spam Folder"));
+    mSpamFolderRequester->setShowOutbox(false);
+    mSpamFolderCheck = new QCheckBox(i18nc("@option:check", "Spam &folder:"), tab);
+    connect(mSpamFolderCheck, &QCheckBox::toggled, mSpamFolderRequester, &MailCommon::FolderRequester::setEnabled);
+    formLayout->addRow(mSpamFolderCheck, mSpamFolderRequester);
+    auto expirePushButton = new QPushButton(i18n("Configure Expire Folder..."), this);
+    connect(expirePushButton, &QPushButton::clicked, this, [this]() {
+        IdentityExpireSpamFolderDialog d(this);
+        d.load(mSpamFolderRequester->collection());
+        d.exec();
+    });
+    expirePushButton->setEnabled(false);
+    connect(mSpamFolderCheck, &QCheckBox::toggled, expirePushButton, &QPushButton::setEnabled);
+    formLayout->addWidget(expirePushButton);
+
     // "Special transport" combobox and label:
     mTransportCheck = new QCheckBox(i18nc("@option:check", "Outgoing Account:"), tab);
     mTransportCombo = new TransportComboBox(tab);
@@ -1046,6 +1065,18 @@ void IdentityDialog::setIdentity(KIdentityManagementCore::Identity &ident)
     } else {
         mTemplatesFolderRequester->setCollection(Akonadi::Collection(ident.templates().toLongLong()));
     }
+
+    mSpamFolderCheck->setChecked(!ident.disabledSpam());
+    mSpamFolderRequester->setEnabled(mSpamFolderCheck->isChecked());
+    if (ident.spam().isEmpty() || !checkFolderExists(ident.spam())) {
+        if (!ident.disabledSpam()) {
+            foundNoExistingFolder = true;
+            mSpamFolderRequester->setIsInvalidFolder(CommonKernel->spamsCollectionFolder());
+        }
+    } else {
+        mSpamFolderRequester->setCollection(Akonadi::Collection(ident.spam().toLongLong()));
+    }
+
     if (foundNoExistingFolder) {
         mIdentityInvalidFolder->setErrorMessage(i18n("Some custom folder for identity does not exist (anymore); therefore, default folders will be used."));
     }
@@ -1100,7 +1131,9 @@ void IdentityDialog::unregisterSpecialCollection(qint64 colId)
         if (cols.count() != 1) {
             return;
         }
-        Akonadi::SpecialMailCollections::self()->unregisterCollection(cols.first());
+        if (!Akonadi::SpecialMailCollections::self()->unregisterCollection(cols.first())) {
+            qCWarning(KMAIL_LOG) << "Impossible to unregister collection" << cols.first();
+        }
     });
 }
 
@@ -1145,6 +1178,7 @@ void IdentityDialog::updateIdentity(KIdentityManagementCore::Identity &ident)
     ident.setTransport(mTransportCheck->isChecked() ? QString::number(mTransportCombo->currentTransportId()) : QString());
     ident.setDictionary(mDictionaryCombo->currentDictionaryName());
     ident.setDisabledFcc(!mSentMailFolderCheck->isChecked());
+    ident.setDisabledSpam(!mSpamFolderCheck->isChecked());
     Akonadi::Collection collection = mFccFolderRequester->collection();
     if (!ident.fcc().isEmpty()) {
         unregisterSpecialCollection(ident.fcc().toLongLong());
@@ -1154,7 +1188,9 @@ void IdentityDialog::updateIdentity(KIdentityManagementCore::Identity &ident)
         auto attribute = collection.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
         attribute->setIconName(QStringLiteral("mail-folder-sent"));
         // It will also start a CollectionModifyJob
-        Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::SentMail, collection);
+        if (!Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::SentMail, collection)) {
+            qCWarning(KMAIL_LOG) << "Impossible to change special sent mail folder";
+        }
     } else {
         ident.setFcc(QString());
     }
@@ -1168,11 +1204,30 @@ void IdentityDialog::updateIdentity(KIdentityManagementCore::Identity &ident)
         auto attribute = collection.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
         attribute->setIconName(QStringLiteral("document-properties"));
         // It will also start a CollectionModifyJob
-        Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::Drafts, collection);
+        if (!Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::Drafts, collection)) {
+            qCWarning(KMAIL_LOG) << "Impossible to change special draft mail folder";
+        }
     } else {
         ident.setDrafts(QString());
     }
 
+    collection = mSpamFolderRequester->collection();
+    if (ident.spam().isEmpty()) {
+        unregisterSpecialCollection(ident.spam().toLongLong());
+    }
+    if (collection.isValid()) {
+        ident.setSpam(QString::number(collection.id()));
+        auto attribute = collection.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
+        attribute->setIconName(QStringLiteral("mail-mark-junk"));
+        // It will also start a CollectionModifyJob
+        if (!Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::Spam, collection)) {
+            qCWarning(KMAIL_LOG) << "Impossible to change special spam mail folder";
+        }
+        new Akonadi::CollectionModifyJob(collection);
+    } else {
+        ident.setSpam(QString());
+    }
+
     collection = mTemplatesFolderRequester->collection();
     if (ident.templates().isEmpty()) {
         unregisterSpecialCollection(ident.templates().toLongLong());
@@ -1182,7 +1237,9 @@ void IdentityDialog::updateIdentity(KIdentityManagementCore::Identity &ident)
         auto attribute = collection.attribute<Akonadi::EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing);
         attribute->setIconName(QStringLiteral("document-new"));
         // It will also start a CollectionModifyJob
-        Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::Templates, collection);
+        if (!Akonadi::SpecialMailCollections::self()->registerCollection(Akonadi::SpecialMailCollections::Templates, collection)) {
+            qCWarning(KMAIL_LOG) << "Impossible to change special template mail folder";
+        }
         new Akonadi::CollectionModifyJob(collection);
     } else {
         ident.setTemplates(QString());
