@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2017-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "newmessagejob.h"
 #include "kmkernel.h"
-#include <MessageComposer/Composer>
+#include <MessageComposer/ComposerJob>
 
 #include <KMime/Message>
 #include <MessageComposer/MessageHelper>
@@ -48,7 +48,7 @@ void NewMessageJob::start()
 
 void NewMessageJob::slotOpenComposer()
 {
-    KMail::Composer *win = makeComposer(mMsg, false, false, KMail::Composer::New, mNewMessageJobSettings.mIdentity);
+    KMail::Composer *win = makeComposer(mMsg, false, false, KMail::Composer::TemplateContext::New, mNewMessageJobSettings.mIdentity);
 
     win->setCollectionForNewMessage(mCollection);
     // Add the attachment if we have one
