@@ -31,7 +31,6 @@
 // of messages from an IMAP server.
 
 #include "kmcommands.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "kmail_debug.h"
 #include "kmreadermainwin.h"
@@ -129,6 +128,7 @@ using KPIM::ProgressManager;
 using namespace KMime;
 
 using namespace MailCommon;
+using namespace Qt::Literals::StringLiterals;
 
 /// Helper to sanely show an error message for a job
 static void showJobError(KJob *job)
@@ -1560,8 +1560,7 @@ void KMMoveCommand::slotMoveCanceled()
 }
 
 KMTrashMsgCommand::KMTrashMsgCommand(const Akonadi::Collection &srcFolder, const Akonadi::Item::List &msgList, MessageList::Core::MessageItemSetReference ref)
-    : KMCommand()
-    , mRef(ref)
+    : mRef(ref)
 {
     // When trashing items from a virtual collection, they may each have a different
     // trash folder, so we need to handle it here carefully
