@@ -384,6 +384,11 @@ public:
      */
     [[nodiscard]] Akonadi::EntityMimeTypeFilterModel *collectionModel() const override;
 
+    /**
+     * Get the config group to be used for an Akonadi resource.
+     */
+    [[nodiscard]] KConfigGroup resourceConfigGroup(const QString &id);
+
     void recoverDeadLetters();
     void closeAllKMailWindows();
     void cleanup();
@@ -519,7 +524,7 @@ public Q_SLOTS:
     void slotRequestConfigSync();
 
     /**
-     * Sync the config immediatley
+     * Sync the config immediately
      */
     void slotSyncConfig();
 
@@ -555,7 +560,7 @@ private Q_SLOTS:
     KMAIL_NO_EXPORT void slotSystemNetworkStatusChanged(bool isOnline);
     KMAIL_NO_EXPORT void slotCollectionChanged(const Akonadi::Collection &, const QSet<QByteArray> &set);
 
-    KMAIL_NO_EXPORT void slotCheckAccount(Akonadi::ServerManager::State state);
+    KMAIL_NO_EXPORT void slotCheckAccounts(Akonadi::ServerManager::State state);
 
 private:
     KMAIL_NO_EXPORT void viewMessage(const QUrl &url);
@@ -584,7 +589,7 @@ private:
                                       bool forceShowWindow,
                                       bool htmlBody);
 
-    KMAIL_NO_EXPORT void verifyAccount();
+    KMAIL_NO_EXPORT void verifyAccounts();
     KMAIL_NO_EXPORT void resourceGoOnLine();
     KMAIL_NO_EXPORT void openReader(bool onlyCheck, bool startInTray);
     KMAIL_NO_EXPORT QSharedPointer<MailCommon::FolderSettings> currentFolderCollection();
@@ -596,7 +601,7 @@ private:
     bool the_firstStart = false;
     /** are we going down? set from here */
     bool the_shuttingDown = false;
-    /** true unles kmail is closed by session management */
+    /** true unless kmail is closed by session management */
     bool the_firstInstance = false;
 
     KSharedConfig::Ptr mConfig;
