@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 #include <QTreeWidget>
 
@@ -26,11 +25,7 @@ class KCMKontactSummary : public KCModule
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMKontactSummary(QWidget *parent, const QVariantList &args);
-#else
-    explicit KCMKontactSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
-#endif
+    explicit KCMKontactSummary(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
